# 2048 [![Build Status](https://img.shields.io/travis/quantum5/2048.svg?maxAge=43200)](https://travis-ci.org/quantum5/2048) [![Coverage](https://img.shields.io/codecov/c/github/quantum5/2048.svg)](https://codecov.io/gh/quantum5/2048) [![PyPI](https://img.shields.io/pypi/v/2048.svg)](https://pypi.org/project/2048/) [![PyPI - Format](https://img.shields.io/pypi/format/2048.svg)](https://pypi.org/project/2048/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/2048.svg)](https://pypi.org/project/2048/)

My version of 2048 game, with multi-instance support, restored from
an old high school project.

![2048 Preview](https://guanzhong.ca/assets/projects/2048-2fd91615603e0f5fed0299df4524c4494968c7b1d762cbb0209354cfa2215639.png)

## Installation

Run `pip install 2048`.

Run `2048` to play the game. Enjoy.

On Windows, you can run `2048w` to run without the console window.

## Resetting the game

If for some reason, the data files get corrupted or you want to clear the high score...

* On Windows, delete `C:\Users\<yourname>\AppData\Roaming\Quantum\2048`.
* On macOS, delete `/Users/<yourname>/Library/Application Support/2048`.
* On Linux, delete `/home/<yourname>/.local/share/2048`.
